==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/parity/ParityAnalysis.h <==
// public class soot.jimple.toolkits.annotation.parity.ParityAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4ca941ab47adb916 soot_jimple_toolkits_annotation_parity_ParityAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_annotation_parity_ParityAnalysis_H_
#define _JC_soot_jimple_toolkits_annotation_parity_ParityAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Value$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object;

typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct {
	struct _jc_java_lang_String$object	*BOTTOM;
	struct _jc_java_lang_String$object	*EVEN;
	struct _jc_java_lang_String$object	*ODD;
	struct _jc_java_lang_String$object	*TOP;
};
extern _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *);
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$getParity$947acf9fe9c22bd7(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_util_HashMap$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$getParity$947acf9fe9c22bd7;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *);
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getParity$947acf9fe9c22bd7)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_util_HashMap$object *, struct _jc_object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods	soot_jimple_toolkits_annotation_parity_ParityAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs {
	struct _jc_soot_toolkits_graph_UnitGraph$object	*g;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs {
    _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs	soot_jimple_toolkits_annotation_parity_ParityAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs	soot_jimple_toolkits_annotation_parity_ParityAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object {
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_parity_ParityAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_parity_ParityAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/parity/ParityAnalysis.h <==
// public class soot.jimple.toolkits.annotation.parity.ParityAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4ca941ab47adb916 soot_jimple_toolkits_annotation_parity_ParityAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_annotation_parity_ParityAnalysis_H_
#define _JC_soot_jimple_toolkits_annotation_parity_ParityAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_soot_Value$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object;

typedef struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct {
	struct _jc_java_lang_String$object	*BOTTOM;
	struct _jc_java_lang_String$object	*EVEN;
	struct _jc_java_lang_String$object	*ODD;
	struct _jc_java_lang_String$object	*TOP;
};
extern _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$fields_struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$getParity$947acf9fe9c22bd7(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_util_HashMap$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$getParity$947acf9fe9c22bd7;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getParity$947acf9fe9c22bd7)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_util_HashMap$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vmethods	soot_jimple_toolkits_annotation_parity_ParityAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs {
	struct _jc_soot_toolkits_graph_UnitGraph$object	*g;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs {
    _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_refs	soot_jimple_toolkits_annotation_parity_ParityAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$sub_nonrefs	soot_jimple_toolkits_annotation_parity_ParityAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$object {
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$vtype _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_parity_ParityAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_parity_ParityAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_parity_ParityAnalysis_H_ */
